@@ -83,9 +83,6 @@ _search_props(linebreak_t * obj, unichar_t c, propval_t * lbcptr,
 	    case LB_CM:
 		*gcbptr = GB_Extend;
 		break;
-	    case LB_ZJ:
-		*gcbptr = GB_Joiner;
-		break;
 	    case LB_H2:
 		*gcbptr = GB_LV;
 		break;
@@ -101,6 +98,9 @@ _search_props(linebreak_t * obj, unichar_t c, propval_t * lbcptr,
 	    case LB_JT:
 		*gcbptr = GB_T;
 		break;
+	    case LB_RI:
+		*gcbptr = GB_Regional_Indicator;
+		break;
 	    default:
 		*gcbptr = GB_Other;
 		break;
